Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1120)

Unified Diff: src/objects.h

Issue 6723001: Some Isolate usage cleanups in objects.{h,cc}. (Closed)
Patch Set: Created 9 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/objects.cc » ('j') | src/objects-inl.h » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/objects.h
diff --git a/src/objects.h b/src/objects.h
index a5bac543c528a352df3ee737d9dfb9efd61304c2..e0ea06486f009db8c9f96c541fbf6b3bf85fdcd4 100644
--- a/src/objects.h
+++ b/src/objects.h
@@ -3776,7 +3776,8 @@ class Map: public HeapObject {
inline int visitor_id();
inline void set_visitor_id(int visitor_id);
- // Returns the heap this map belongs to.
+ // Returns the isolate/heap this map belongs to.
+ inline Isolate* isolate();
inline Heap* heap();
typedef void (*TraverseCallback)(Map* map, void* data);
« no previous file with comments | « no previous file | src/objects.cc » ('j') | src/objects-inl.h » ('J')

Powered by Google App Engine
This is Rietveld 408576698